// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: google/cloud/bigquery/storage/v1/protobuf.proto
// Protobuf C++ Version: 7.35.1

#include "google/cloud/bigquery/storage/v1/protobuf.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
#ifdef PROTOBUF_MESSAGE_GLOBALS
namespace {
PROTOBUF_CONSTINIT ::google::protobuf::internal::ReflectionData
    file_reflection_data[] = {
        // ::google::cloud::bigquery::storage::v1::ProtoSchema
        {&::_pbi::kDescriptorMethods, &::descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto, /* tracker*/ nullptr,},
        // ::google::cloud::bigquery::storage::v1::ProtoRows
        {&::_pbi::kDescriptorMethods, &::descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto, /* tracker*/ nullptr,},
};
}  // namespace
#endif
namespace google {
namespace cloud {
namespace bigquery {
namespace storage {
namespace v1 {
class ProtoRows::_Internal {
 public:
  using HasBits = decltype(::std::declval<ProtoRows>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ProtoRows, _impl_._has_bits_);
};

constexpr ProtoRows::ParseTableT_ ProtoRows::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ProtoRows, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::ProtoRows>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // repeated bytes serialized_rows = 1;
      {::_pbi::TcParser::FastBR1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(ProtoRows, _impl_.serialized_rows_)}},
    }}, {{
      65535, 65535
    }}, {{
      // repeated bytes serialized_rows = 1;
      {PROTOBUF_FIELD_OFFSET(ProtoRows, _impl_.serialized_rows_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kBytes | ::_fl::kRepSString)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr ProtoRows::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        serialized_rows_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::google::cloud::bigquery::storage::v1::ProtoRows,
            PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ProtoRows, _impl_.serialized_rows_)>()
         }
     {}

template <typename>
constexpr ProtoRows::ProtoRows(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ProtoRows::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ProtoRows(arena);
}
constexpr auto ProtoRows::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(ProtoRows), alignof(ProtoRows));
}
constexpr auto ProtoRows::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &ProtoRows::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ProtoRows>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ProtoRows::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ProtoRows>(), &ProtoRows::ByteSizeLong,
              &ProtoRows::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ProtoRows, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[1],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ProtoRowsGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ProtoRowsGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ProtoRows_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ProtoRows::InternalGenerateClassData_(
            _default, &ProtoRows_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ProtoRows>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ProtoRowsGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ProtoRows _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ProtoRows>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ProtoRowsGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ProtoRowsGlobalsTypeInternal ProtoRows_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ProtoRows_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ProtoRows_globals_.GetClassData();
#else
  return ProtoRows_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class ProtoSchema::_Internal {
 public:
  using HasBits = decltype(::std::declval<ProtoSchema>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ProtoSchema, _impl_._has_bits_);
};

constexpr ProtoSchema::ParseTableT_ ProtoSchema::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ProtoSchema, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::ProtoSchema>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // .google.protobuf.DescriptorProto proto_descriptor = 1;
      {::_pbi::TcParser::FastMtS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(ProtoSchema, _impl_.proto_descriptor_)}},
    }}, {{
      65535, 65535
    }}, {{
      // .google.protobuf.DescriptorProto proto_descriptor = 1;
      {PROTOBUF_FIELD_OFFSET(ProtoSchema, _impl_.proto_descriptor_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::protobuf::DescriptorProto>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::protobuf::DescriptorProto_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr ProtoSchema::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        proto_descriptor_{nullptr} {}

template <typename>
constexpr ProtoSchema::ProtoSchema(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ProtoSchema::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ProtoSchema(arena);
}
constexpr auto ProtoSchema::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(ProtoSchema), alignof(ProtoSchema));
}
constexpr auto ProtoSchema::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          ProtoSchema::IsInitializedImpl,
          &ProtoSchema::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ProtoSchema>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ProtoSchema::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ProtoSchema>(), &ProtoSchema::ByteSizeLong,
              &ProtoSchema::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ProtoSchema, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[0],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ProtoSchemaGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ProtoSchemaGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ProtoSchema_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ProtoSchema::InternalGenerateClassData_(
            _default, &ProtoSchema_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ProtoSchema>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ProtoSchemaGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ProtoSchema _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ProtoSchema>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ProtoSchemaGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ProtoSchemaGlobalsTypeInternal ProtoSchema_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ProtoSchema_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ProtoSchema_globals_.GetClassData();
#else
  return ProtoSchema_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
}  // namespace v1
}  // namespace storage
}  // namespace bigquery
}  // namespace cloud
}  // namespace google
static constexpr const ::_pb::EnumDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_enum_descriptors_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto = nullptr;
static constexpr const ::_pb::ServiceDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_service_descriptors_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto = nullptr;
const ::uint32_t
    TableStruct_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ProtoSchema, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ProtoSchema, _impl_.proto_descriptor_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ProtoRows, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ProtoRows, _impl_.serialized_rows_),
        0,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::google::cloud::bigquery::storage::v1::ProtoSchema)},
        {5, sizeof(::google::cloud::bigquery::storage::v1::ProtoRows)},
};
static const ::_pbi::MessageGlobalsBase* PROTOBUF_NONNULL const
    file_message_globals[] = {
        &::google::cloud::bigquery::storage::v1::ProtoSchema_globals_,
        &::google::cloud::bigquery::storage::v1::ProtoRows_globals_,
};
const char descriptor_table_protodef_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n/google/cloud/bigquery/storage/v1/proto"
    "buf.proto\022 google.cloud.bigquery.storage"
    ".v1\032 google/protobuf/descriptor.proto\"I\n"
    "\013ProtoSchema\022:\n\020proto_descriptor\030\001 \001(\0132 "
    ".google.protobuf.DescriptorProto\"$\n\tProt"
    "oRows\022\027\n\017serialized_rows\030\001 \003(\014B\275\001\n$com.g"
    "oogle.cloud.bigquery.storage.v1B\rProtoBu"
    "fProtoP\001Z>cloud.google.com/go/bigquery/s"
    "torage/apiv1/storagepb;storagepb\252\002 Googl"
    "e.Cloud.BigQuery.Storage.V1\312\002 Google\\Clo"
    "ud\\BigQuery\\Storage\\V1b\006proto3"
};
static const ::_pbi::DescriptorTable* PROTOBUF_NONNULL const
    descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto_deps[1] = {
        &::descriptor_table_google_2fprotobuf_2fdescriptor_2eproto,
};
static ::absl::once_flag descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto = {
    false,
    false,
    430,
    descriptor_table_protodef_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto,
    "google/cloud/bigquery/storage/v1/protobuf.proto",
    &descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto_once,
    descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto_deps,
    1,
    2,
    schemas,
    file_message_globals,
    TableStruct_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto::offsets,
    file_level_enum_descriptors_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto,
    file_level_service_descriptors_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto,
};
namespace google {
namespace cloud {
namespace bigquery {
namespace storage {
namespace v1 {
// ===================================================================

void ProtoSchema::clear_proto_descriptor() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.proto_descriptor_ != nullptr) _impl_.proto_descriptor_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
ProtoSchema::ProtoSchema(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ProtoSchema_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:google.cloud.bigquery.storage.v1.ProtoSchema)
}
PROTOBUF_NDEBUG_INLINE ProtoSchema::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::google::cloud::bigquery::storage::v1::ProtoSchema& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

ProtoSchema::ProtoSchema(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ProtoSchema& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ProtoSchema_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ProtoSchema* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.proto_descriptor_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.proto_descriptor_)
                : nullptr;

  // @@protoc_insertion_point(copy_constructor:google.cloud.bigquery.storage.v1.ProtoSchema)
}
PROTOBUF_NDEBUG_INLINE ProtoSchema::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void ProtoSchema::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.proto_descriptor_ = {};
}
ProtoSchema::~ProtoSchema() {
  // @@protoc_insertion_point(destructor:google.cloud.bigquery.storage.v1.ProtoSchema)
  SharedDtor(*this);
}
inline void ProtoSchema::SharedDtor(MessageLite& self) {
  ProtoSchema& this_ = static_cast<ProtoSchema&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.proto_descriptor_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ProtoSchema_class_data_ =
        ProtoSchema::InternalGenerateClassData_(ProtoSchema_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ProtoSchema::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ProtoSchema_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ProtoSchema_class_data_.tc_table);
  return ProtoSchema_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ProtoSchema::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ProtoSchema_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ProtoSchema_globals_));
  return ProtoSchema_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ProtoSchema::ParseTableT_
    ProtoSchema::_table_ =
        ProtoSchema::InternalGenerateParseTable_(ProtoSchema_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ProtoSchema::Clear() {
// @@protoc_insertion_point(message_clear_start:google.cloud.bigquery.storage.v1.ProtoSchema)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    ABSL_DCHECK(_impl_.proto_descriptor_ != nullptr);
    _impl_.proto_descriptor_->Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ProtoSchema::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ProtoSchema& this_ = static_cast<const ProtoSchema&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ProtoSchema::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ProtoSchema& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:google.cloud.bigquery.storage.v1.ProtoSchema)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .google.protobuf.DescriptorProto proto_descriptor = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.proto_descriptor_, this_._impl_.proto_descriptor_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:google.cloud.bigquery.storage.v1.ProtoSchema)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ProtoSchema::ByteSizeLong(const MessageLite& base) {
  const ProtoSchema& this_ = static_cast<const ProtoSchema&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ProtoSchema::ByteSizeLong() const {
  const ProtoSchema& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:google.cloud.bigquery.storage.v1.ProtoSchema)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

   {
    // .google.protobuf.DescriptorProto proto_descriptor = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.proto_descriptor_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ProtoSchema::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ProtoSchema*>(&to_msg);
  auto& from = static_cast<const ProtoSchema&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:google.cloud.bigquery.storage.v1.ProtoSchema)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    ABSL_DCHECK(from._impl_.proto_descriptor_ != nullptr);
    if (_this->_impl_.proto_descriptor_ == nullptr) {
      _this->_impl_.proto_descriptor_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.proto_descriptor_);
    } else {
      _this->_impl_.proto_descriptor_->MergeFrom(*from._impl_.proto_descriptor_);
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ProtoSchema::CopyFrom(const ProtoSchema& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:google.cloud.bigquery.storage.v1.ProtoSchema)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool ProtoSchema::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const ProtoSchema&>(msg);
  if (CheckHasBit(this_._impl_._has_bits_[0], 0x00000001U)) {
    if (!this_._impl_.proto_descriptor_->IsInitialized()) return false;
  }
  return true;
}

void ProtoSchema::InternalSwap(ProtoSchema* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.proto_descriptor_, other->_impl_.proto_descriptor_);
}

::google::protobuf::Metadata ProtoSchema::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

ProtoRows::ProtoRows(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ProtoRows_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:google.cloud.bigquery.storage.v1.ProtoRows)
}
PROTOBUF_NDEBUG_INLINE ProtoRows::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::google::cloud::bigquery::storage::v1::ProtoRows& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        serialized_rows_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::google::cloud::bigquery::storage::v1::ProtoRows,
              PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ProtoRows, _impl_.serialized_rows_)>()
          , from.serialized_rows_
        }
     {}

ProtoRows::ProtoRows(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ProtoRows& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ProtoRows_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ProtoRows* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:google.cloud.bigquery.storage.v1.ProtoRows)
}
PROTOBUF_NDEBUG_INLINE ProtoRows::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        serialized_rows_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::google::cloud::bigquery::storage::v1::ProtoRows,
            PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ProtoRows, _impl_.serialized_rows_)>()
         }
     {}

inline void ProtoRows::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
ProtoRows::~ProtoRows() {
  // @@protoc_insertion_point(destructor:google.cloud.bigquery.storage.v1.ProtoRows)
  SharedDtor(*this);
}
inline void ProtoRows::SharedDtor(MessageLite& self) {
  ProtoRows& this_ = static_cast<ProtoRows&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ProtoRows_class_data_ =
        ProtoRows::InternalGenerateClassData_(ProtoRows_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ProtoRows::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ProtoRows_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ProtoRows_class_data_.tc_table);
  return ProtoRows_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ProtoRows::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ProtoRows_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ProtoRows_globals_));
  return ProtoRows_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ProtoRows::ParseTableT_
    ProtoRows::_table_ =
        ProtoRows::InternalGenerateParseTable_(ProtoRows_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ProtoRows::Clear() {
// @@protoc_insertion_point(message_clear_start:google.cloud.bigquery.storage.v1.ProtoRows)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.serialized_rows_.Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ProtoRows::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ProtoRows& this_ = static_cast<const ProtoRows&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ProtoRows::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ProtoRows& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:google.cloud.bigquery.storage.v1.ProtoRows)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated bytes serialized_rows = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (int i = 0, n = this_._internal_serialized_rows_size(); i < n; ++i) {
      const auto& s = this_._internal_serialized_rows().Get(i);
      target = stream->WriteBytes(1, s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:google.cloud.bigquery.storage.v1.ProtoRows)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ProtoRows::ByteSizeLong(const MessageLite& base) {
  const ProtoRows& this_ = static_cast<const ProtoRows&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ProtoRows::ByteSizeLong() const {
  const ProtoRows& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:google.cloud.bigquery.storage.v1.ProtoRows)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated bytes serialized_rows = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size +=
          1 * ::google::protobuf::internal::FromIntSize(this_._internal_serialized_rows().size());
      for (int i = 0, n = this_._internal_serialized_rows().size(); i < n; ++i) {
        total_size += ::google::protobuf::internal::WireFormatLite::BytesSize(
            this_._internal_serialized_rows().Get(i));
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ProtoRows::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ProtoRows*>(&to_msg);
  auto& from = static_cast<const ProtoRows&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:google.cloud.bigquery.storage.v1.ProtoRows)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_internal_mutable_serialized_rows()->InternalMergeFromWithArena(
        ::google::protobuf::MessageLite::internal_visibility(), arena,
        from._internal_serialized_rows());
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ProtoRows::CopyFrom(const ProtoRows& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:google.cloud.bigquery.storage.v1.ProtoRows)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ProtoRows::InternalSwap(ProtoRows* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.serialized_rows_.InternalSwap(&other->_impl_.serialized_rows_);
}

::google::protobuf::Metadata ProtoRows::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace v1
}  // namespace storage
}  // namespace bigquery
}  // namespace cloud
}  // namespace google
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
