// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: google/api/field_behavior.proto
// Protobuf C++ Version: 7.35.1

#ifndef google_2fapi_2ffield_5fbehavior_2eproto_2epb_2eh
#define google_2fapi_2ffield_5fbehavior_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

// clang-format off
#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 7035001
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/generated_enum_reflection.h"
#include "google/protobuf/descriptor.pb.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_google_2fapi_2ffield_5fbehavior_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_google_2fapi_2ffield_5fbehavior_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_google_2fapi_2ffield_5fbehavior_2eproto;
}  // extern "C"
namespace google {
namespace api {
enum FieldBehavior : int;
extern const uint32_t FieldBehavior_internal_data_[];
}  // namespace api
namespace protobuf {
template <>
internal::EnumTraitsT<::google::api::FieldBehavior_internal_data_>
    internal::EnumTraitsImpl::value<::google::api::FieldBehavior>;
}  // namespace protobuf
}  // namespace google

namespace google {
namespace api {
enum FieldBehavior : int {
  FIELD_BEHAVIOR_UNSPECIFIED = 0,
  OPTIONAL = 1,
  REQUIRED = 2,
  OUTPUT_ONLY = 3,
  INPUT_ONLY = 4,
  IMMUTABLE = 5,
  UNORDERED_LIST = 6,
  NON_EMPTY_DEFAULT = 7,
  FieldBehavior_INT_MIN_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::min(),
  FieldBehavior_INT_MAX_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::max(),
};

extern const uint32_t FieldBehavior_internal_data_[];
inline constexpr FieldBehavior FieldBehavior_MIN =
    static_cast<FieldBehavior>(0);
inline constexpr FieldBehavior FieldBehavior_MAX =
    static_cast<FieldBehavior>(7);
[[nodiscard]] inline bool FieldBehavior_IsValid(int value) {
  return 0 <= value && value <= 7;
}
inline constexpr int FieldBehavior_ARRAYSIZE = 7 + 1;
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
FieldBehavior_descriptor();
[[nodiscard]] inline auto ProtobufInternalGetEnumDescriptor(FieldBehavior) {
  return FieldBehavior_descriptor();
}
template <typename T>
[[nodiscard]] const ::std::string& FieldBehavior_Name(T value) {
  static_assert(::std::is_same<T, FieldBehavior>::value ||
                    ::std::is_integral<T>::value,
                "Incorrect type passed to FieldBehavior_Name().");
  return FieldBehavior_Name(static_cast<FieldBehavior>(value));
}
template <>
[[nodiscard]] inline const ::std::string& FieldBehavior_Name(FieldBehavior value) {
  return ::google::protobuf::internal::NameOfDenseEnum<FieldBehavior_descriptor, 0, 7>(
      static_cast<int>(value));
}
[[nodiscard]] inline bool FieldBehavior_Parse(
    ::absl::string_view name, FieldBehavior* PROTOBUF_NONNULL value) {
  return ::google::protobuf::internal::ParseNamedEnum<FieldBehavior>(FieldBehavior_descriptor(), name,
                                           value);
}
using ::google::protobuf::internal::generated_enum::AbslParseFlag;
using ::google::protobuf::internal::generated_enum::AbslUnparseFlag;

// ===================================================================



// ===================================================================



inline constexpr int kFieldBehaviorFieldNumber = 1052;
extern ::google::protobuf::internal::ExtensionIdentifier<
    ::google::protobuf::FieldOptions, ::google::protobuf::internal::RepeatedEnumTypeTraits< ::google::api::FieldBehavior>, 14, true>(field_behavior);

// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace api
}  // namespace google


namespace google {
namespace protobuf {

template <>
struct is_proto_enum<::google::api::FieldBehavior> : std::true_type {};
template <>
inline const EnumDescriptor* PROTOBUF_NONNULL GetEnumDescriptor<::google::api::FieldBehavior>() {
  return ::google::api::FieldBehavior_descriptor();
}

}  // namespace protobuf
}  // namespace google

// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"
// clang-format on

#endif  // google_2fapi_2ffield_5fbehavior_2eproto_2epb_2eh
